% La fonction "xpMC_spl" estime le moment d'ordre 4 de la loi normale
% standard par la méthode de Monte-Carlo “naïve”. Elle prend en argument le
% nombre "N" de simulations demandées.
function xplMC_spl(N)
% "S" contiendra la somme des résultats simulés, et "S2" la somme des
% carrés des résultats.
S = 0;
S2 = 0;
% On déclenche le chronomètre.
tic;
% On lance la boucle de simulations.
for i = 1:N
    % f est une simulation de la loi dont on veut évaluer l'espérance.
    f = randn^4;
    % On met à jour "S" et "S2".
    S = S + f;
    S2 = S2 + f * f;
end
% On arrête le chronomètre, et on appelle "t" le temps écoulé.
t = toc;
% On calcule les estimateurs "m" de la moyenne et "sigma" de l'écart-type.
m = S / N;
sigma = sqrt(S2 / N - m * m);
% "marge" est la marge d'erreur à 98 % de confiance, soit 2,33 sigmas.
marge = 2.33 * sigma / sqrt(N);
% On affiche le résultat ainsi que le temps de calcul.
disp(['Estimateur et intervalle de confiance à 98 % : ',...
    num2str(m,'%7f'),' ± ',num2str(marge)]);
disp(['Temps de calcul : ',num2str(t),' s']);
% Le programme s'arrête.
return
end

