% La fonction "xplMC_vec" fait la même chose que "xplMC_spl", mais en
% regroupant les simulations par 20 pour exploiter les capacités
% vectorielles de MATLAB. Seuls les points différant de "xplMC_spl" sont
% commentés.
function xplMC_vec(N)
S = 0;
S2 = 0;
tic;
% On lance la boucle de simulations. Comme chaque passage dans la boucle
% fournit 20 simulations, il n'y a que N/20 passages à effectuer. (N est
% supposé multiple de 20).
for i = 1:N/20
    % f est un 20-vecteur de simulations indépendantes de la loi dont on
    % veut évaluer l'espérance; on utilise pour le simuler la version
    % vectorielle du générateur d'aléa "randn" ainsi que la vesrion
    % vectorielle '.^' de l'opération puissance.
    f = randn(1,20).^4;
    % On met à jour "S" et "S2". Notez qu'il faut d'abord sommer les
    % 20-vecteurs de résultats obtenus. ".*" est la version vectorielle de
    % l'opération multiplication.
    S = S + sum(f);
    S2 = S2 + sum(f .* f);
end
t = toc;
m = S / N;
sigma = sqrt(S2 / N - m * m);
marge = 2.33 * sigma / sqrt(N);
disp(['Estimateur et intervalle de confiance à 98 % : ',...
    num2str(m,'%7f'),' ± ',num2str(marge)]);
disp(['Temps de calcul : ',num2str(t),' s']);
return
end

